AuthInfo class

Constructors

AuthInfo(List<SignerInfo>? signer_infos, Fee fee)

Properties

fee → Fee
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signer_infos ↔ List<SignerInfo>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toData() → AuthInfoDataArgs
toJson() → TxAuthInfo
toProto() → Uint8List
toProtoWithType() → AuthInfo
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromBytes(List<int> data) → AuthInfo
fromData(AuthInfoDataArgs data) → AuthInfo
fromJSON(TxAuthInfo data) → AuthInfo