Fee class

Constructors

Fee(double gas_limit, List<Coin> amount, {String? payer = "", String? granter = ""})

Properties

amount → List<Coin>
final
gas_limit → double
final
granter ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
payer ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

gasPrices() → List<Coin>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAmino() → FeeAminoArgs
toData() → FeeDataArgs
toJson() → TxFee
toProto() → Uint8List
toProtoWithType() → Fee
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromAmino(FeeAminoArgs data) → Fee
fromData(FeeDataArgs data) → Fee
fromJSON(TxFee data) → Fee
fromProto(Fee data) → Fee