ModeInfo class

Constructors

ModeInfo(dynamic data)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single ↔ SignatureV2Single?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toData() → ModeInfoDataArgs
toJSON() → TxSignerModeInfo
toProto() → Uint8List
toProtoWithType() → ModeInfo
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromData(ModeInfoDataArgs data) → ModeInfo
fromJSON(TxSignerModeInfo data) → ModeInfo
fromProto(ModeInfo data) → ModeInfo