SignDoc class

Constructors

SignDoc(String chain_id, double account_number, double sequence, AuthInfo auth_info, {TxBody? tx_body})

Properties

account_number → double
final
auth_info → AuthInfo
final
chain_id → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequence → double
final
tx_body ↔ TxBody?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAmino() → SignDocAminoArgs
toData() → SignDocDataArgs
toProto({List<TxUploadMessageData>? messages}) → Uint8List
toProtoWithType({List<TxUploadMessageData>? messages}) → SignDoc
toString() → String
A string representation of this object.
inherited
toUnsignedTx() → Tx

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromData(SignDocDataArgs data) → SignDoc