TxBody class

Constructors

TxBody(List<Any>? messages, String memo, double timeout_height)

Properties

hashCode → int
The hash code for this object.
no setterinherited
memo → String
final
messages ↔ List<Any>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeout_height → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toData() → TxBodyDataArgs
toJsonForUpload(List<TxUploadMessageData> msgs) → TxUploadBodyJSON
toProto({List<TxUploadMessageData>? messages}) → Uint8List
toProtoWithType({List<TxUploadMessageData>? messages}) → TxBody
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromData(TxBodyDataArgs data) → TxBody